@@ -53,9 +53,9 @@ public:
 	
 	//! starts the creation of a new clause
 	/*!
-	 * \pre s.decisionLevel() == 0 || t != Constraint_t::native_constraint
+	 * \pre s.decisionLevel() == 0 || t != Constraint_t::static_constraint
 	 */
-	ClauseCreator& start(ConstraintType t = Constraint_t::native_constraint);
+	ClauseCreator& start(ConstraintType t = Constraint_t::static_constraint);
 	
 	//! start the creation of an asserting or unit clause.
 	/*!
@@ -95,7 +95,7 @@ public:
 	 * \param sw    The position of the second watched literal in lits
 	 * \param[out]  A pointer to the newly created clause or 0 if no clause object was created
 	 *
-	 * \pre !s.hasConflict() and s.decisionLevel() == 0 or t != Constraint_t::native_constraint
+	 * \pre !s.hasConflict() and s.decisionLevel() == 0 or t != Constraint_t::static_constraint
 	 * \pre lits does not contain duplicate/complementary literals
 	 * \pre the clause is not conflicting
 	 * \pre lits is empty or lits[0] is either free or true
@@ -242,7 +242,7 @@ public:
 	 * \note if the clause is a learnt clause, calling reason increases
 	 * the clause's activity.
 	 */
-	void reason(const Literal& p, LitVec& lits);
+	ConstraintType reason(const Literal& p, LitVec& lits);
 
 	//! returns true if clause is SAT.
 	/*!
@@ -280,7 +280,7 @@ public:
 	
 	//! halves the activity of this clause
 	void decreaseActivity() {
-		if (type() != Constraint_t::native_constraint) {
+		if (type() != Constraint_t::static_constraint) {
 			act() >>= 1;
 		}
 	}
@@ -346,7 +346,7 @@ private:
 	
 	uint32& act() { return lits_[0].asUint(); }
 	void bumpActivity() {
-		if (type_ != Constraint_t::native_constraint) {
+		if (type_ != Constraint_t::static_constraint) {
 			++act();
 		}
 	}
@@ -427,7 +427,7 @@ public:
 	// Constraint interface
 	
 	PropResult propagate(const Literal& p, uint32& data, Solver& s);
-	void reason(const Literal& p, LitVec& lits);
+	ConstraintType reason(const Literal& p, LitVec& lits);
 	bool simplify(Solver& s, bool = false);
 	void destroy();
 	
