@@ -108,6 +108,26 @@ bool StreamSource::readLine( char* buf, unsigned maxSize ) {
 	*buf = 0;
 	return maxSize != 0;
 }
+
+bool readLine(StreamSource& in, PodVector<char>::type& buf ) {
+	char   buffer[1024];
+	uint32 i;
+	buf.clear();
+	for (i = 0;;) {
+		buffer[i] = *in;
+		++in;
+		if (buffer[i] == '\n' || buffer[i] == '\0') {
+			buf.insert(buf.end(), buffer, buffer+i+1);
+			buf.back() = '\0';
+			break;
+		}
+		if (++i == 1024) {
+			buf.insert(buf.end(), buffer, buffer+i);
+			i = 0;
+		}
+	}
+	return buffer[i] == '\n';
+}
 	
 namespace {
 /////////////////////////////////////////////////////////////////////////////////////////
@@ -246,16 +266,17 @@ bool LparseReader::readBody(uint32 lits, uint32 neg, bool readWeights) {
 
 bool LparseReader::readSymbolTable() {
 	int a = -1;
+	PodVector<char>::type buf;
+	buf.reserve(1024);
 	while (source_->parseInt(a) && a != 0) {
 		if (a < 1) {
 			throw ReadError(source_->line(), "Symbol Table: Atom id out of bounds!");
 		}
-		char buffer[1024];
 		source_->skipWhite();
-		if (!source_->readLine(buffer, 1024)) {
+		if (!readLine(*source_, buf)) {
 			throw ReadError(source_->line(), "Symbol Table: Atom name too long or end of file!");
 		}
-		api_->setAtomName(a, buffer);
+		api_->setAtomName(a, &buf[0]);
 		skipAllWhite(*source_);
 	}
 	if (a != 0) {
@@ -326,7 +347,7 @@ bool parseDimacsImpl(std::istream& prg, Solver& s, bool assertPure) {
 	PodVector<uint8>::type flags;
 	for (;ret;) {
 		skipAllWhite(in);
-		if (*in == 0) {
+		if (*in == 0 && numVars != -1) {
 			break;
 		}
 		else if (*in == 'p') {
@@ -516,11 +537,19 @@ void OPBParser::parseSum() {
 void OPBParser::addConstraint(const char* relOp, int rhs) {
 	if (good()) {
 		if (relOp != 0) {
-			// True == lhs >= rhs
-			WeightConstraint::newWeightConstraint(solver_, posLit(0), lhs_, rhs);
-			if (relOp[0] == '=') {
-				// False == lhs >= rhs+1
-				WeightConstraint::newWeightConstraint(solver_, negLit(0), lhs_, rhs+1);
+			if (relOp[0] == '>') {
+				assert(relOp[1] == '=');
+				// TRUE == [lhs >= rhs]
+				WeightConstraint::newWeightConstraint(solver_, posLit(0), lhs_, rhs);	
+			}
+			else {
+				assert(relOp[0] == '=');
+				// replace TRUE == [lhs = rhs] with
+				// TRUE  == [lhs >= rhs]   and
+				// FALSE == [lhs >= rhs+1]
+				WeightLitVec temp(lhs_); // copy because newWeightConstraint() removes assigned literals 
+				WeightConstraint::newWeightConstraint(solver_, posLit(0), lhs_, rhs) &&
+				WeightConstraint::newWeightConstraint(solver_, negLit(0), temp, rhs+1);
 			}
 		}
 		else {
