@@ -18,7 +18,7 @@
 #ifndef _GRINGO_H
 #define _GRINGO_H
 
-#define GRINGO_VERSION "3.0.4"
+#define GRINGO_VERSION "3.0.5"
 
 #include <gringo/val.h>
 #include <gringo/clone_ptr.h>
@@ -76,7 +76,6 @@ class Index;
 class Instantiator;
 class Lexer;
 class Lit;
-class Loc;
 class LuaLit;
 class LuaTerm;
 class LparseConverter;
@@ -99,10 +98,10 @@ class VarCollector;
 class VarTerm;
 class WeightLit;
 class IncLit;
-class IncConfig;
+struct IncConfig;
 class Streams;
-class TermExpansion;
 
+struct TermExpansion;
 struct Loc;
 
 namespace LitDep
@@ -130,12 +129,22 @@ typedef std::pair<Loc, uint32_t> VarSig;
 typedef std::vector<VarSig> VarSigVec;
 typedef std::auto_ptr<TermExpansion> TermExpansionPtr;
 
-Term* new_clone(const Term& a);
-VarTerm* new_clone(const VarTerm& a);
-Lit* new_clone(const Lit& a);
-WeightLit* new_clone(const WeightLit& a);
-Instantiator* new_clone(const Instantiator& a);
-LitDep::GrdNode* new_clone(const LitDep::GrdNode& a);
-CondLit* new_clone(const CondLit& a);
+namespace boost
+{
+	template <>
+	Term* new_clone(const Term& a);
+	template <>
+	VarTerm* new_clone(const VarTerm& a);
+	template <>
+	Lit* new_clone(const Lit& a);
+	template <>
+	WeightLit* new_clone(const WeightLit& a);
+	template <>
+	Instantiator* new_clone(const Instantiator& a);
+	template <>
+	LitDep::GrdNode* new_clone(const LitDep::GrdNode& a);
+	template <>
+	CondLit* new_clone(const CondLit& a);
+}
 
 #endif
