@@ -35,9 +35,12 @@ private:
 	IntVec new_;
 };
    
-inline Instantiator* new_clone(const Instantiator& a)
+namespace boost
 {
-	(void)a;
-	return 0;
+	template <>
+	inline Instantiator* new_clone(const Instantiator& a)
+	{
+		(void)a;
+		return 0;
+	}
 }
-
