@@ -47,6 +47,10 @@ Term *ArgTerm::clone() const
 	return new ArgTerm(*this);
 }
 
+double ArgTerm::estimate(VarSet const &, double) const {
+    return 1;
+}
+
 ArgTerm::~ArgTerm()
 {
 }
