@@ -57,3 +57,6 @@ Term *ConstTerm::clone() const
 	return new ConstTerm(*this);
 }
 
+double ConstTerm::estimate(VarSet const &, double) const {
+    return 1;
+}
