@@ -71,6 +71,10 @@ Term *PoolTerm::clone() const
 	else return new PoolTerm(loc(), a_.release());
 }
 
+double PoolTerm::estimate(VarSet const &, double) const {
+    return 1;
+}
+
 PoolTerm::~PoolTerm()
 {
 }
